Changelog
=========

0.1.1 (2022-07-13)
------------------

 * Confirm Django 4.x support
 * Fix Django 3.0 and 3.1 compatibility by providing a default_app_config setting


0.1 (2021-05-08)
----------------

* Initial release
